@@ -1,5 +1,5 @@
 /* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>
-  
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
@@ -7,12 +7,12 @@
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -22,7 +22,7 @@
 #include <BackgroundJobs/HandleVideoThumbnailRequestJob.h>
 #include <ImageManager/ExtractOneVideoFrame.h>
 #include <QImage>
-#include <Utilities/Util.h>
+#include <Utilities/ImageUtil.h>
 #include <DB/ImageDB.h>
 #include <QPainter>
 #include <QFile>
@@ -36,7 +36,7 @@ ExtractOneThumbnailJob::ExtractOneThumbnailJob(const DB::FileName& fileName, int
 }
 
 void ExtractOneThumbnailJob::execute()
-{    
+{
     if ( m_wasCanceled || frameName().exists() )
         emit completed();
     else {
