@@ -42,7 +42,7 @@ class BrowserPage: public QObject
     Q_OBJECT
 public:
      BrowserPage( const DB::ImageSearchInfo& info, BrowserWidget* browser );
-     virtual ~BrowserPage() {}
+     ~BrowserPage() override {}
 
     /**
      * Construct the page. Result of activation may be to call \ref BrowserWidget::addAction.
