@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,7 @@
 #include "Settings/SettingsData.h"
 #include <QApplication>
 #include <Utilities/BooleanGuard.h>
-#include "Utilities/Util.h"
+#include "Utilities/FileUtil.h"
 #include <cmath>
 
 const int CELLWIDTH = 200;
