@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2015 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -71,7 +71,7 @@ int Browser::TreeCategoryModel::rowCount(const QModelIndex& index) const
 
 int Browser::TreeCategoryModel::columnCount(const QModelIndex&) const
 {
-    return 3;
+    return 5;
 }
 
 QModelIndex Browser::TreeCategoryModel::index(int row, int column, const QModelIndex& parent) const
@@ -112,8 +112,8 @@ Browser::TreeCategoryModel::~TreeCategoryModel()
 bool Browser::TreeCategoryModel::createData(DB::CategoryItem* parentCategoryItem, Data* parent)
 {
     const QString name = parentCategoryItem->mp_name;
-    const int imageCount = m_images.contains(name) ? m_images[name] : 0;
-    const int videoCount = m_videos.contains(name) ? m_videos[name] : 0;
+    const int imageCount = m_images.contains(name) ? m_images[name].count : 0;
+    const int videoCount = m_videos.contains(name) ? m_videos[name].count : 0;
 
     Data* myData = new Data(name);
     bool anyItems = imageCount != 0 || videoCount != 0;
