@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,6 +18,8 @@
 #ifndef CATEGORY_H
 #define CATEGORY_H
 
+#include "ImageDate.h"
+
 #include <QDate>
 #include <QExplicitlySharedDataPointer>
 #include <QObject>
@@ -31,6 +33,15 @@ namespace DB
 {
 class CategoryItem;
 
+struct CountWithRange {
+    uint count = 0;
+    ImageDate range {};
+    void add(const ImageDate &date) {
+        count++;
+        range.extendTo(date);
+    }
+};
+
 
 /**
    This class stores information about categories (People/Places/Events)
