@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,21 +33,25 @@
 #include <MainWindow/Logging.h>
 #include <MainWindow/Window.h>
 #include <Settings/SettingsData.h>
-#include <Utilities/Util.h>
+#include <Utilities/FileUtil.h>
+#include <Utilities/FileNameUtil.h>
+#include <Utilities/VideoUtil.h>
 
 #include <QApplication>
+#include <QDataStream>
+#include <QElapsedTimer>
 #include <QEventLoop>
+#include <QFile>
 #include <QFileInfo>
+#include <QImageReader>
 #include <QLoggingCategory>
+#include <QMimeDatabase>
 #include <QProgressBar>
 #include <QProgressDialog>
 #include <QStringList>
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QDataStream>
-#include <QFile>
-#include <QElapsedTimer>
 
 using namespace DB;
 
@@ -223,7 +227,7 @@ using namespace DB;
  * Note also that hdparm does a single stream read from the device.
  * It does not take advantage of the ability to queue multiple
  * requests.
- * 
+ *
  *
  * ANALYSIS OF KPHOTOALBUM LOAD PERFORMANCE
  * -------- -- ----------- ---- -----------
@@ -245,13 +249,13 @@ using namespace DB;
  * The ALL set consists of 10839 or 10840 images totaling about 92 GB
  *   (the above set plus 2 .MOV files and in some cases one additional
  *   JPEG file).
- * 
+ *
  * Times are elapsed times; CPU consumption is approximate user+system
  * CPU consumption.  Numbers in parentheses are with thumbnail
  * building disabled.  Note that in the cases with no scout threads on
  * the SSD the times were reproducibly shorter with thumbnail building
  * enabled (reasons are not determined at this time).
- * 
+ *
  * Cases building RAW thumbnails generally consumed somewhat more
  * system CPU (in the range of 10-15%) than JPEG-only cases.  This may
  * be due to custom I/O routines used for generating thumbnails with
@@ -260,37 +264,37 @@ using namespace DB;
  *
  * Estimating CPU time for mixed workloads proved very problematic,
  * as there were significant changes over time.
- * 
+ *
  * Elapsed Time
  * ------- ----
- * 
+ *
  *                                 SSD                     HDD
- * 
+ *
  * JPG - 0 scouts                  4:03 (3:59)
  * JPG - 1 scout                   2:46 (2:44)
  * JPG - 2 scouts                  2:20 (2:07)
  * JPG - 3 scouts                  2:21 (1:58)
- * 
+ *
  * ALL - 0 scouts                  6:32 (7:03)            16:01
  * ALL - 1 scout                   4:33 (4:33)            15:01
  * ALL - 2 scouts                  3:37 (3:28)            16:59
  * ALL - 3 scouts                  3:36 (3:15)
- * 
+ *
  * RAW - 0 scouts                  2:18 (2:46)
  * RAW - 1 scout                   1:46 (1:46)
  * RAW - 2 scouts                  1:17 (1:17)
  * RAW - 3 scouts                  1:13 (1:13)
- * 
+ *
  * User+System CPU
  * ----------- ---
- * 
+ *
  *                                 SSD                     HDD
- * 
+ *
  * JPG - 0 scouts                  40% (12%)
  * JPG - 1 scout                   70% (20%)
  * JPG - 2 scouts                  85% (15%)
  * JPG - 3 scouts                  85% (15%)
- * 
+ *
  * RAW - 0 scouts                  15% (10%)
  * RAW - 1 scout                   18% (12%)
  * RAW - 2 scouts                  25% (15%)
@@ -305,22 +309,22 @@ using namespace DB;
  * larger size of RAW files but possibly also related to the smaller
  * filesize of embedded thumbnails (on the Canon 7D mkII, the embedded
  * thumbnail is full size but low quality).
- * 
+ *
  * With thumbnail generation:
  * ---- --------- -----------
- * 
+ *
  *                                 RAW             JPEG
- * 
+ *
  * Thumbnail generation            44%             82%
  *   libjpeg processing              43%             82%
  * MD5 computation                 51%             13%
  * Read Exif                        1%              1.0%
- * 
+ *
  * Without thumbnail generation:
  * ------- --------- -----------
- * 
+ *
  *                                 RAW             JPEG
- * 
+ *
  * MD5 computation                 92%             80%
  * Read Exif                        4%             10%
  *
@@ -371,6 +375,18 @@ namespace {
 // yields about 10% less performance with higher IO/sec but lower I/O throughput,
 // most probably due to thrashing.
 constexpr int IMAGE_SCOUT_THREAD_COUNT = 1;
+
+
+bool canReadImage( const DB::FileName& fileName )
+{
+    bool fastMode = !Settings::SettingsData::instance()->ignoreFileExtension();
+    QMimeDatabase::MatchMode mode = fastMode ? QMimeDatabase::MatchExtension : QMimeDatabase::MatchDefault;
+    QMimeDatabase db;
+    QMimeType mimeType = db.mimeTypeForFile( fileName.absolute(), mode );
+
+    return QImageReader::supportedMimeTypes().contains( mimeType.name().toUtf8() )
+            || ImageManager::ImageDecoder::mightDecode( fileName );
+}
 }
 
 bool NewImageFinder::findImages()
@@ -446,7 +462,7 @@ void NewImageFinder::searchForNewFiles( const DB::FileNameSet& loadedFiles, QStr
 
         if ( fi.isFile() ) {
             if ( ! DB::ImageDB::instance()->isBlocking( file ) ) {
-                if ( Utilities::canReadImage(file) )
+                if ( canReadImage(file) )
                     m_pendingLoad.append( qMakePair( file, DB::Image ) );
                 else if ( Utilities::isVideo( file ) )
                     m_pendingLoad.append( qMakePair( file, DB::Video ) );
@@ -528,7 +544,7 @@ void NewImageFinder::setupFileVersionDetection() {
 
 void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaType type )
 {
-    MD5 sum = Utilities::MD5Sum( newFileName );
+    MD5 sum = MD5Sum( newFileName );
     if ( handleIfImageHasBeenMoved(newFileName, sum) )
         return;
 
@@ -704,7 +720,7 @@ bool  NewImageFinder::calculateMD5sums(
             }
         }
 
-        MD5 md5 = Utilities::MD5Sum( fileName );
+        MD5 md5 = MD5Sum( fileName );
         if (md5.isNull()) {
             cantRead << fileName;
             continue;
