@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -43,12 +43,35 @@
 #include <Exif/Info.h>
 #include <ImageManager/AsyncLoader.h>
 #include <ImportExport/Export.h>
-#include <Utilities/Util.h>
+#include <Utilities/FileUtil.h>
+#include <Utilities/VideoUtil.h>
 
 #include "ImageSizeCheckBox.h"
 #include "Setup.h"
 #include "MainWindow/Window.h"
 
+namespace {
+QString readFile( const QString& fileName )
+{
+    if ( fileName.isEmpty() ) {
+        KMessageBox::error( nullptr, i18n("<p>No file name given!</p>") );
+        return QString();
+    }
+
+    QFile file( fileName );
+    if ( !file.open( QIODevice::ReadOnly ) ) {
+        //KMessageBox::error( nullptr, i18n("Could not open file %1").arg( fileName ) );
+        return QString();
+    }
+
+    QTextStream stream( &file );
+    QString content = stream.readAll();
+    file.close();
+
+    return content;
+}
+} //namespace
+
 HTMLGenerator::Generator::Generator( const Setup& setup, QWidget* parent )
     : QProgressDialog( parent )
     , m_tempDirHandle()
@@ -159,7 +182,7 @@ void HTMLGenerator::Generator::generate()
             *it == QString::fromLatin1("imagepage.html")) continue;
         QString from = QString::fromLatin1("%1%2").arg( themeDir ).arg(*it);
         QString to = m_tempDir.filePath(*it);
-        ok = Utilities::copy( from, to );
+        ok = Utilities::copyOrOverwrite( from, to );
         if ( !ok ) {
             KMessageBox::error( this, i18n("Error copying %1 to %2", from , to ) );
             return;
@@ -181,7 +204,7 @@ bool HTMLGenerator::Generator::generateIndexPage( int width, int height )
 {
     QString themeDir, themeAuthor, themeName;
     getThemeInfo( &themeDir, &themeName, &themeAuthor );
-    QString content = Utilities::readFile( QString::fromLatin1( "%1mainpage.html" ).arg( themeDir ) );
+    QString content = readFile( QString::fromLatin1( "%1mainpage.html" ).arg( themeDir ) );
     if ( content.isEmpty() )
         return false;
 
@@ -392,7 +415,7 @@ bool HTMLGenerator::Generator::generateContentPage( int width, int height,
 {
     QString themeDir, themeAuthor, themeName;
     getThemeInfo( &themeDir, &themeName, &themeAuthor );
-    QString content = Utilities::readFile( QString::fromLatin1( "%1imagepage.html" ).arg( themeDir ));
+    QString content = readFile( QString::fromLatin1( "%1imagepage.html" ).arg( themeDir ));
     if ( content.isEmpty() )
         return false;
 
@@ -600,7 +623,7 @@ QString HTMLGenerator::Generator::createVideo( const DB::FileName& fileName )
                 .arg( destName.replace( QRegExp( QString::fromLatin1("\\..*") ), QString::fromLatin1(".ogg") ) )
                 .arg( QString::fromLatin1( "320" ) ).arg( fileName.absolute() ), MainWindow::Window::theMainWindow() );
         } else
-            Utilities::copy( fileName.absolute(), destName );
+            Utilities::copyOrOverwrite( fileName.absolute(), destName );
         m_copiedVideos.insert( fileName );
     }
     return baseName;
@@ -650,7 +673,7 @@ bool HTMLGenerator::Generator::linkIndexFile()
                        .arg(resolution->text(true));
     fromFile = m_tempDir.filePath(fromFile);
     QString destFile = m_tempDir.filePath( QString::fromLatin1("index.html") );
-    bool ok = Utilities::copy( fromFile, destFile );
+    bool ok = Utilities::copyOrOverwrite( fromFile, destFile );
     if ( !ok ) {
         KMessageBox::error( this, i18n("<p>Unable to copy %1 to %2</p>"
                             , fromFile , destFile ) );
