@@ -27,8 +27,8 @@ namespace ImageManager
 
 class RAWImageDecoder : public ImageDecoder {
 public:
-    virtual bool _decode(QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1);
-    virtual bool _mightDecode( const DB::FileName& imageFile );
+    bool _decode(QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim=-1) override;
+    bool _mightDecode( const DB::FileName& imageFile ) override;
     virtual bool _skipThisFile( const DB::FileNameSet& loadedFiles, const DB::FileName& imageFile ) const;
     static bool isRAW( const DB::FileName& imageFile );
     static QStringList rawExtensions();
