@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -36,7 +36,7 @@
 ImageManager::ThumbnailBuilder* ImageManager::ThumbnailBuilder::s_instance = nullptr;
 
 ImageManager::ThumbnailBuilder::ThumbnailBuilder( MainWindow::StatusBar* statusBar, QObject* parent )
-    :QObject( parent ), 
+    :QObject( parent ),
      m_statusBar( statusBar ),
      m_count( 0 ),
      m_isBuilding( false ),
@@ -94,8 +94,8 @@ void ImageManager::ThumbnailBuilder::pixmapLoaded(ImageManager::ImageRequest* re
 void ImageManager::ThumbnailBuilder::buildAll( ThumbnailBuildStart when )
 {
     QMessageBox msgBox;
-    msgBox.setText(QString::fromLatin1("Buliding all thumbnails may take a long time."));
-    msgBox.setInformativeText(QString::fromLatin1("Do you want to rebuild all of your thumbnails?"));
+    msgBox.setText(i18n("Building all thumbnails may take a long time."));
+    msgBox.setInformativeText(i18n("Do you want to rebuild all of your thumbnails?"));
     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
     msgBox.setDefaultButton(QMessageBox::No);
     int ret = msgBox.exec();
@@ -111,6 +111,11 @@ ImageManager::ThumbnailBuilder* ImageManager::ThumbnailBuilder::instance()
     return s_instance;
 }
 
+ImageManager::ThumbnailBuilder::~ThumbnailBuilder()
+{
+    terminateScout();
+}
+
 void ImageManager::ThumbnailBuilder::buildMissing()
 {
     const DB::FileNameList images = DB::ImageDB::instance()->images();
