@@ -1,4 +1,4 @@
-/* Copyright (C) 2010-2018 Miika Turkia <miika.turkia@gmail.com>
+/* Copyright (C) 2010-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -38,8 +38,9 @@
 #include <DB/ImageInfo.h>
 #include <DB/MD5Map.h>
 #include <MainWindow/Window.h>
+#include <Settings/SettingsData.h>
 #include <Utilities/ShowBusyCursor.h>
-#include <Utilities/Util.h>
+#include <Utilities/FileUtil.h>
 
 using namespace MainWindow;
 
@@ -67,7 +68,7 @@ AutoStackImages::AutoStackImages( QWidget* parent, const DB::FileNameList& list
     m_matchingFile = new QCheckBox( i18n( "Stack images based on file version detection") );
     m_matchingFile->setChecked( true );
     hlayFile->addWidget( m_matchingFile );
- 
+
     m_origTop = new QCheckBox( i18n( "Original to top") );
     m_origTop ->setChecked( false );
     hlayFile->addWidget( m_origTop );
@@ -183,7 +184,7 @@ void AutoStackImages::matchingFile( DB::FileNameList& toBeShown )
     QString modifiedFileCompString;
     QRegExp modifiedFileComponent;
     QStringList originalFileComponents;
- 
+
     modifiedFileCompString = Settings::SettingsData::instance()->modifiedFileComponent();
     modifiedFileComponent = QRegExp( modifiedFileCompString );
 
@@ -219,7 +220,7 @@ void AutoStackImages::matchingFile( DB::FileNameList& toBeShown )
             }
         }
     }
-    
+
     // Then add images to stack (depending on configuration options)
     for( QMap<DB::MD5, DB::FileNameList >::ConstIterator it = tostack.constBegin(); it != tostack.constEnd(); ++it ) {
         if ( tostack[it.key()].count() > 1 ) {
