@@ -49,6 +49,7 @@ public:
 
 signals:
     void cancelRequest();
+    void thumbnailSettingsRequested();
 
 protected:
     void enterEvent(QEvent *event) override;
@@ -56,7 +57,6 @@ protected:
 private slots:
     void hideStatusBar();
     void showStatusBar();
-    void checkSliderValue(int);
 
 private:
     void setupGUI();
@@ -67,8 +67,7 @@ private:
     QToolButton* m_cancel;
     QTimer* m_pendingShowTimer;
     QSlider* m_thumbnailSizeSlider;
-    QToolButton* m_thumbnailsSmaller;
-    QToolButton* m_thumbnailsBigger;
+    QToolButton* m_thumbnailSettings;
 };
 
 }
