@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2014 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -52,7 +52,7 @@ Settings::TagGroupsPage::TagGroupsPage(QWidget* parent) : QWidget(parent)
     m_categoryTreeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
     layout->addWidget(m_categoryTreeWidget, 1, 0);
     connect(m_categoryTreeWidget, &CategoriesGroupsWidget::customContextMenuRequested, this, &TagGroupsPage::showTreeContextMenu);
-    connect(m_categoryTreeWidget, &CategoriesGroupsWidget::itemActivated, this, &TagGroupsPage::slotGroupSelected);
+    connect(m_categoryTreeWidget, &CategoriesGroupsWidget::itemClicked, this, &TagGroupsPage::slotGroupSelected);
 
     // The member list
     m_selectGroupToAddTags = i18nc("@label/rich","<strong>Select a group on the left side to add tags to it</strong>");
@@ -469,18 +469,15 @@ void Settings::TagGroupsPage::slotRenameGroup()
                                                    m_currentSubCategory,
                                                    &ok
                                                    );
-    // workaround until validation with GUI support is reimplemented:
-    if (groups.contains(newSubCategoryName))
-        return;
 
     if (! ok || m_currentSubCategory == newSubCategoryName) {
         return;
     }
 
-    if (m_memberMap.groups(m_currentCategory).contains(newSubCategoryName)) {
+    if (groups.contains(newSubCategoryName)) {
         // (with the validator working correctly, we should not get to this point)
         KMessageBox::sorry(this,
-                            i18nc("@info","<para>Cannot rename group \"%1\" to \"%2\": "
+                            xi18nc("@info","<para>Cannot rename group \"%1\" to \"%2\": "
                                 "\"%2\" already exists in category \"%3\"</para>",
                                  m_currentSubCategory,
                                  newSubCategoryName,
@@ -542,13 +539,13 @@ void Settings::TagGroupsPage::slotDeleteGroup()
     QString title;
 
     if (currentItem->childCount() > 0) {
-        message = i18nc("@info","<para>Really delete group \"%1\"?</para>"
+        message = xi18nc("@info","<para>Really delete group \"%1\"?</para>"
                 "<para>Sub-categories of this group will be moved to the super category of \"%1\" (\"%2\").<nl/> "
                 "All other memberships of the sub-categories will stay intact.</para>",
                 m_currentSubCategory,
                 m_currentSuperCategory);
     } else {
-        message = i18nc("@info","<para>Really delete group \"%1\"?</para>", m_currentSubCategory);
+        message = xi18nc("@info","<para>Really delete group \"%1\"?</para>", m_currentSubCategory);
     }
 
     int res = KMessageBox::warningContinueCancel(this,
@@ -794,7 +791,7 @@ void Settings::TagGroupsPage::slotDeleteMember()
     } else {
         // The item to delete is a normal tag
         int res = KMessageBox::warningContinueCancel(this,
-            i18nc("@info","<para>Do you really want to delete \"%1\"?</para>"
+            xi18nc("@info","<para>Do you really want to delete \"%1\"?</para>"
                  "<para>Deleting the item will remove any information "
                  "about it from any image containing the item.</para>",
                  memberToDelete),
