@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,7 +35,7 @@
 #include <DB/ImageInfo.h>
 #include <DB/MemberMap.h>
 #include <Settings/SettingsData.h>
-#include <Utilities/Util.h>
+#include <Utilities/FileUtil.h>
 
 using Utilities::StringSet;
 
