@@ -24,29 +24,17 @@
 #include "NumberedBackup.h"
 #include "XMLCategory.h"
 
+#include <DB/UIDelegate.h>
 #include <MainWindow/Logging.h>
-#include <MainWindow/Window.h>
 #include <Settings/SettingsData.h>
 #include <Utilities/List.h>
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QFile>
 #include <QXmlStreamWriter>
 #include <QFileInfo>
 
-// I've added this to provide anyone interested
-// with a quick and easy means to benchmark performance differences
-// between old and new save behaviour.
-// Note: in Qt4, saving files was deterministic "by accident"; with Qt5, we have to work for it
-// (mostly because QSet is randomized now)
-// FIXME(ZaJ): this should be removed "soon" (at latest by KPA 5.2.0)
-#define DETERMINISTIC_DBSAVE
-
-// print saving time:
-//#define BENCHMARK_FILEWRITER
-
 //
 //
 //
@@ -73,17 +61,19 @@ void XMLDB::FileWriter::save( const QString& fileName, bool isAutoSave )
     setUseCompressedFileFormat( Settings::SettingsData::instance()->useCompressedIndexXML() );
 
     if ( !isAutoSave )
-        NumberedBackup().makeNumberedBackup();
+        NumberedBackup(m_db->uiDelegate()).makeNumberedBackup();
 
     // prepare XML document for saving:
     m_db->m_categoryCollection.initIdMap();
     QFile out(fileName + QString::fromLatin1(".tmp"));
     if ( !out.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        KMessageBox::sorry( messageParent(),
-                            i18n("<p>Could not save the image database to XML.</p>"
-                                 "File %1 could not be opened because of the following error: %2"
-                                 , out.fileName(), out.errorString() )
-                            );
+        m_db->uiDelegate().sorry(
+                    QString::fromUtf8("Error saving to file '%1': %2").arg(out.fileName()).arg(out.errorString())
+                    , i18n("<p>Could not save the image database to XML.</p>"
+                           "File %1 could not be opened because of the following error: %2"
+                           , out.fileName(), out.errorString() )
+                    , i18n("Error while saving...")
+                    );
         return;
     }
     QTime t;
@@ -112,21 +102,25 @@ void XMLDB::FileWriter::save( const QString& fileName, bool isAutoSave )
     // original file can be safely deleted
     if ( ( ! QFile::remove( fileName ) ) && QFile::exists( fileName ) )
     {
-        KMessageBox::sorry( messageParent(),
-                            i18n("<p>Failed to remove old version of image database.</p>"
-                                 "<p>Please try again or replace the file %1 with file %2 manually!</p>",
-                                 fileName, out.fileName() )
-                            );
+        m_db->uiDelegate().sorry(
+                    QString::fromUtf8("Removal of file '%1' failed.").arg(fileName)
+                    , i18n("<p>Failed to remove old version of image database.</p>"
+                           "<p>Please try again or replace the file %1 with file %2 manually!</p>",
+                           fileName, out.fileName() )
+                    , i18n("Error while saving...")
+                    );
         return;
     }
     // State: index.xml doesn't exist, index.xml.tmp has the current version.
     if ( ! out.rename( fileName ) )
     {
-        KMessageBox::sorry( messageParent(),
-                            i18n("<p>Failed to move temporary XML file to permanent location.</p>"
-                                 "<p>Please try again or rename file %1 to %2 manually!</p>",
-                                 out.fileName(), fileName )
-                            );
+        m_db->uiDelegate().sorry(
+                    QString::fromUtf8("Renaming index.xml to '%1' failed.").arg(out.fileName())
+                    , i18n("<p>Failed to move temporary XML file to permanent location.</p>"
+                           "<p>Please try again or rename file %1 to %2 manually!</p>",
+                           out.fileName(), fileName )
+                    , i18n("Error while saving...")
+                    );
         // State: index.xml.tmp has the current version.
         return;
     }
@@ -201,13 +195,9 @@ void XMLDB::FileWriter::saveImages( QXmlStreamWriter& writer )
 void XMLDB::FileWriter::saveBlockList( QXmlStreamWriter& writer )
 {
     ElementWriter dummy( writer, QString::fromLatin1( "blocklist" ) );
-#ifdef DETERMINISTIC_DBSAVE
     QList<DB::FileName> blockList = m_db->m_blockList.toList();
     // sort blocklist to get diffable files
     std::sort(blockList.begin(), blockList.end());
-#else
-    QSet<DB::FileName> blockList = m_db->m_blockList;
-#endif
     Q_FOREACH(const DB::FileName &block, blockList) {
         ElementWriter dummy( writer,  QString::fromLatin1( "block" ) );
         writer.writeAttribute( QString::fromLatin1( "file" ), block.relative() );
@@ -256,18 +246,12 @@ void XMLDB::FileWriter::saveMemberGroups( QXmlStreamWriter& writer )
                         qCWarning(XMLDBLog) << "Member" << member << "in group" << categoryName << "->" << groupMapIt.key() << "has no id!";
                     idList.append( QString::number( category->idForName( member ) ) );
                 }
-#ifdef DETERMINISTIC_DBSAVE
                 std::sort(idList.begin(), idList.end());
-#endif
                 writer.writeAttribute( QString::fromLatin1( "members" ), idList.join( QString::fromLatin1( "," ) ) );
             }
             else {
-#ifdef DETERMINISTIC_DBSAVE
                 QStringList members = groupMapIt.value().toList();
                 std::sort(members.begin(), members.end());
-#else
-                QSet<QString> members = groupMapIt.value();
-#endif
                 Q_FOREACH(const QString& member, members) {
                     ElementWriter dummy( writer,  QString::fromLatin1( "member" ) );
                     writer.writeAttribute( QString::fromLatin1( "category" ), memberMapIt.key() );
@@ -377,12 +361,8 @@ void XMLDB::FileWriter::writeCategories( QXmlStreamWriter& writer, const DB::Ima
 
         ElementWriter categoryElm(writer, QString::fromLatin1("option"), false );
 
-#ifdef DETERMINISTIC_DBSAVE
         QStringList items = info->itemsOfCategory(name).toList();
         std::sort(items.begin(), items.end());
-#else
-        QSet<QString> items = info->itemsOfCategory(name);
-#endif
         if ( !items.isEmpty() ) {
             topElm.writeStartElement();
             categoryElm.writeStartElement();
@@ -433,9 +413,7 @@ void XMLDB::FileWriter::writeCategoriesCompressed( QXmlStreamWriter& writer, con
             // write the category attribute if there are actually ids to write
             if ( !idList.isEmpty() )
             {
-#ifdef DETERMINISTIC_DBSAVE
                 std::sort(idList.begin(), idList.end());
-#endif
                 writer.writeAttribute( escape( categoryName ), idList.join( QString::fromLatin1( "," ) ) );
             }
         }
@@ -527,10 +505,4 @@ QString XMLDB::FileWriter::escape( const QString& str )
     return tmp;
 }
 
-// TODO(hzeller): DEPENDENCY This pulls in the whole MainWindow dependency into the database backend.
-QWidget *XMLDB::FileWriter::messageParent()
-{
-    return MainWindow::Window::theMainWindow();
-}
-
 // vi:expandtab:tabstop=4 shiftwidth=4:
