@@ -1,4 +1,4 @@
-/* Copyright (C) 2010-2018 The KPhotoAlbum development team
+/* Copyright (C) 2010-2019 The KPhotoAlbum development team
    Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
@@ -69,35 +69,38 @@ int main( int argc, char** argv ) {
             QStringLiteral(KPA_VERSION),
             i18n("KDE Photo Album"), // short description
             KAboutLicense::GPL,
-            QString(),  // copyright statement
+            i18n("Copyright (C) 2003-2019 The KPhotoAlbum Development Team"),  // copyright statement
             QString(),  // other text
-            QStringLiteral("http://www.kphotoalbum.org") // homepage
+            QStringLiteral("https://www.kphotoalbum.org") // homepage
             );
     aboutData.setOrganizationDomain("kde.org");
-    aboutData.addAuthor( i18n("Jesper K. Pedersen"), i18n("Development"), QStringLiteral("blackie@kde.org") );
-    aboutData.addAuthor( i18n("Hassan Ibraheem"),i18n("Development"), QStringLiteral("hasan.ibraheem@gmail.com"));
-    aboutData.addAuthor( i18n("Miika Turkia"),i18n("Development"), QStringLiteral("miika.turkia@gmail.com"));
-    aboutData.addAuthor( i18n("Tuomas Suutari"), i18n("SQL backend and numerous features"), QStringLiteral("thsuut@utu.fi") );
-    aboutData.addAuthor( i18n("Jan Kundr&aacute;t"), i18n("Development"), QStringLiteral("jkt@gentoo.org"));
-    aboutData.addAuthor( i18n("Henner Zeller"),i18n("Development"), QStringLiteral("h.zeller@acm.org"));
-    aboutData.addAuthor( i18n("Andreas Neustifter"),i18n("Development"), QStringLiteral("andreas.neustifter@gmail.com"));
-    aboutData.addAuthor( i18n("Johannes Zarl-Zierl"),i18n("Development"), QStringLiteral("johannes@zarl-zierl.at"));
-    aboutData.addAuthor( i18n("Tobias Leupold"),i18n("Development"), QStringLiteral("tobias.leupold@gmx.de"));
-    aboutData.addAuthor( i18n("Robert Krawitz"),i18n("Development"), QStringLiteral("rlk@alum.mit.edu"));
+    // maintainer is expected to be the first entry
+    // Note: I like to sort by name, grouped by active/inactive;
+    //       Jesper gets ranked with the active authors for obvious reasons
+    aboutData.addAuthor( i18n("Johannes Zarl-Zierl"),i18n("Development, Maintainer"), QStringLiteral("johannes@zarl-zierl.at"));
+    aboutData.addAuthor( i18n("Robert Krawitz"),i18n("Development, Optimization"), QStringLiteral("rlk@alum.mit.edu"));
+    aboutData.addAuthor( i18n("Tobias Leupold"),i18n("Development, Releases, Website"), QStringLiteral("tobias.leupold@gmx.de"));
+    aboutData.addAuthor( i18n("Jesper K. Pedersen"), i18n("Former Maintainer, Project Creator"), QStringLiteral("blackie@kde.org") );
+    // not currently active:
+    aboutData.addAuthor( i18n("Hassan Ibraheem"),QString(), QStringLiteral("hasan.ibraheem@gmail.com"));
+    aboutData.addAuthor( i18n("Jan Kundr&aacute;t"), QString(), QStringLiteral("jkt@gentoo.org"));
+    aboutData.addAuthor( i18n("Andreas Neustifter"),QString(), QStringLiteral("andreas.neustifter@gmail.com"));
+    aboutData.addAuthor( i18n("Tuomas Suutari"), QString(), QStringLiteral("thsuut@utu.fi") );
+    aboutData.addAuthor( i18n("Miika Turkia"),QString(), QStringLiteral("miika.turkia@gmail.com"));
+    aboutData.addAuthor( i18n("Henner Zeller"),QString(), QStringLiteral("h.zeller@acm.org"));
 
-    aboutData.addCredit( i18n("Will Stephenson"), i18n("Developing an Icon for KPhotoAlbum"), QStringLiteral("will@stevello.free-online.co.uk") );
-    aboutData.addCredit( i18n("Teemu Rytilahti"),
-                         i18n("Sending patches implementing (.) the \"Set As Wallpaper\" menu in the viewer."
-                         "(.) Theme support for HTML generation"), QStringLiteral("teemu.rytilahti@kde-fi.org") );
-    aboutData.addCredit( i18n("Reimar Imhof"), i18n("Patch to sort items in option listboxes"), QStringLiteral("Reimar.Imhof@netCologne.de") );
-    aboutData.addCredit( i18n("Thomas Schwarzgruber"), i18n("Patch to sort images in the thumbnail view, plus reading time info out of Exif images for existing images"), QStringLiteral("possebaer@gmx.at") );
-    aboutData.addCredit( i18n("Marcel Wiesweg"), i18n("Patch which speed up loading of thumbnails plus preview in image property dialog."), QStringLiteral("marcel.wiesweg@gmx.de") );
+    // sort alphabetically:
     aboutData.addCredit( i18n("Marco Caldarelli"), i18n("Patch for making it possible to reread Exif info using a nice dialog."), QStringLiteral("caldarel@yahoo.it") );
     aboutData.addCredit( i18n("Jean-Michel FAYARD"), i18n("(.) Patch with directory info made available through the browser. (.) Patch for adding a check box for \"and/or\" searches in the search page."), QStringLiteral("jmfayard@gmail.com") );
-    aboutData.addCredit( i18n("Robert L Krawitz"), i18n("Numerous patches plus profiling KPhotoAlbum again and again."), QStringLiteral("rlk@alum.mit.edu") );
-    aboutData.addCredit( i18n("Christoph Moseler"), i18n("Numerous patches for lots of bugs plus patches for a few new features"), QStringLiteral("forums@moseler.net") );
-    aboutData.addCredit( i18n("Clytie Siddall"), i18n("Tremendous help with the English text in the application."), QStringLiteral("clytie@riverland.net.au") );
     aboutData.addCredit( i18n("Wes Hardaker"),i18n("Some very useful features to improve workflow"), QStringLiteral("kpa@capturedonearth.com"));
+    aboutData.addCredit( i18n("Reimar Imhof"), i18n("Patch to sort items in option listboxes"), QStringLiteral("Reimar.Imhof@netCologne.de") );
+    aboutData.addCredit( i18n("Christoph Moseler"), i18n("Numerous patches for lots of bugs plus patches for a few new features"), QStringLiteral("forums@moseler.net") );
+    aboutData.addCredit( i18n("Teemu Rytilahti"),
+                         i18n("Theme support for HTML generation"), QStringLiteral("teemu.rytilahti@kde-fi.org") );
+    aboutData.addCredit( i18n("Thomas Schwarzgruber"), i18n("Patch to sort images in the thumbnail view, plus reading time info out of Exif images for existing images"), QStringLiteral("possebaer@gmx.at") );
+    aboutData.addCredit( i18n("Clytie Siddall"), i18n("Tremendous help with the English text in the application."), QStringLiteral("clytie@riverland.net.au") );
+    aboutData.addCredit( i18n("Will Stephenson"), i18n("Developing an Icon for KPhotoAlbum"), QStringLiteral("will@stevello.free-online.co.uk") );
+    aboutData.addCredit( i18n("Marcel Wiesweg"), i18n("Patch which speed up loading of thumbnails plus preview in image property dialog."), QStringLiteral("marcel.wiesweg@gmx.de") );
 
     // initialize the commandline parser
     QCommandLineParser *parser = MainWindow::Options::the()->parser();
